@@ -19,7 +19,9 @@ set -eux
 
 export OVERCLOUD_DIB_EXTRA_ARGS=pypi
 export NODE_ARCH=amd64
+THROTTLELOCK=$(mktemp /tmp/tripleo-cd-throttle-XXXXXX.lock)
 while true; do
+    flock -x $THROTTLELOCK sleep 600 &
     source /opt/stack/tripleo-incubator/scripts/refresh-env /opt/stack
     source /root/stackrc
     set +e
@@ -29,11 +31,19 @@ while true; do
         $TRIPLEO_ROOT/tripleo-incubator/tripleo-cloud/tripleo-cd-admins \
         $TRIPLEO_ROOT/tripleo-incubator/tripleo-cloud/tripleo-cd-users
     RESULT=$?
+    # List relationship between hardware nodes and instance ids.
+    for i in $(nova baremetal-node-list | awk '/^\| / {if ($2 != "ID") {print $2}}') ; do
+        instance_id=$(nova baremetal-node-show $i | awk '/instance_uuid/ {print $4}')
+        echo "$i,$instance_id"
+    done
+    nova list
     set -e
     MSG=$(echo "************** overcloud complete status=$RESULT ************")
     echo "$MSG"
     send-irc tripleo cd-undercloud "$MSG"
+    flock -x $THROTTLELOCK echo
     if [ "0" != "$RESULT" ]; then
+        rm -f $THROTTLELOCK
         exit $RESULT
     fi
 done
